import React from "react";
import { Control, FieldValues, FormState, UseFormGetValues, UseFormRegister, UseFormSetValue, UseFormWatch, UseFormTrigger, UseFormReset, UseFormResetField } from "react-hook-form";
import * as yup from 'yup';
import { Locale } from "date-fns";
import { Size } from "./utils";
export interface FormRenderContext<T extends FieldValues> {
    control: Control<T>;
    register: UseFormRegister<T>;
    setValue: UseFormSetValue<T>;
    getValues: UseFormGetValues<T>;
    schema: yup.ObjectSchema<any>;
    watch: UseFormWatch<T>;
    formEnabled: boolean;
    formState: FormState<T>;
    isSubmitAllowed: boolean;
    locale: Locale;
    trigger: UseFormTrigger<T>;
    reset: UseFormReset<T>;
    resetField: UseFormResetField<T>;
    size: Size;
}
export type OnSubmitFnType<T extends FieldValues> = (data: T, context: FormRenderContext<T>) => void;
export type OnChangeFnType<T extends FieldValues> = (data: T, context: FormRenderContext<T>, field: string | undefined, type: string | undefined) => void;
export interface OctoFormProps<T extends FieldValues> {
    defaultValues: T;
    schema: yup.ObjectSchema<any>;
    onSubmit: OnSubmitFnType<T>;
    onChange?: OnChangeFnType<T>;
    children?: React.ReactNode;
    formEnabled?: boolean;
    locale?: Locale;
    size?: Size;
}
export declare const OctoFormContext: React.Context<FormRenderContext<any>>;
export declare function OctoForm<T extends FieldValues>({ defaultValues, schema, onSubmit, onChange, children, formEnabled, locale, size }: OctoFormProps<T>): import("react/jsx-runtime").JSX.Element;
